<?php
/*------------------------------------------------------------------------
  Solidres - Hotel booking extension for Joomla
  ------------------------------------------------------------------------
  @Author    Solidres Team
  @Website   http://www.solidres.com
  @Copyright Copyright (C) 2013 - 2016 Solidres. All Rights Reserved.
  @License   GNU General Public License version 3, or later
------------------------------------------------------------------------*/

defined('_JEXEC') or die;

/**
 * Solidres Component Controller
 *
 * @package     Solidres
 * @since 		0.1.0
 */
class SolidresController extends SRControllerLegacy
{
	/**
	 * Method to display a view.
	 *
	 * @param	boolean			$cachable If true, the view output will be cached
	 * @param	boolean			$urlparams An array of safe url parameters and their variable types, for valid values see {@link JFilterInput::clean()}.
	 *
	 * @return	JControllerLegacy		This object to support chaining.
	 * @since	1.5
	 */
	public function display($cachable = false, $urlparams = false)
	{
		$cachable = true;

		JHtml::stylesheet('com_solidres/assets/main.min.css', false, true);

		$safeurlparams = array(
			'catid'            => 'INT',
			'id'               => 'INT',
			'cid'              => 'ARRAY',
			'year'             => 'INT',
			'month'            => 'INT',
			'limit'            => 'INT',
			'limitstart'       => 'INT',
			'showall'          => 'INT',
			'return'           => 'BASE64',
			'filter'           => 'STRING',
			'filter_order'     => 'CMD',
			'filter_order_Dir' => 'CMD',
			'filter-search'    => 'STRING',
			'print'            => 'BOOLEAN',
			'lang'             => 'CMD',
			'location'         => 'STRING',
			'categories'       => 'STRING',
			'mode'             => 'STRING',
			'Itemid'           => 'UINT'
		);

		$viewName = $this->input->get('view');
		$user = JFactory::getUser();
		$solidresConfig = JComponentHelper::getParams('com_solidres');
		$partnerUserGroups = $solidresConfig->get('partner_user_groups', array());
		$partnerUserGroups = array_values($partnerUserGroups);
		asort($partnerUserGroups);
		$customerUserGroups = $solidresConfig->get('customer_user_groups', array());
		$customerUserGroups = array_values($customerUserGroups);
		asort($customerUserGroups);
		$userGroups = array_values($user->groups);
		asort($userGroups);
		JPluginHelper::importPlugin('solidres');
		JEventDispatcher::getInstance()->trigger('onSolidresBeforeDisplay', array($viewName, &$cachable, &$safeurlparams));

		switch ($viewName)
		{
			case 'customer':

				if ($user->get('guest') == 1)
				{
					// Redirect to login page.
					$return = JRoute::_('index.php?option=com_solidres&view=customer', false);
					$this->setRedirect(JRoute::_('index.php?option=com_users&view=login&return=' . base64_encode($return), false));

					return;
				}

				foreach ($customerUserGroups as $customerUserGroup)
				{
					if (!in_array($customerUserGroup, $userGroups))
					{
						JError::raiseError(403, JText::_('JERROR_ALERTNOAUTHOR'));

						return false;
					}
				}

				$modelReservations = JModelLegacy::getInstance('MyReservations', 'SolidresModel', array('ignore_request' => false));
				$modelAsset = JModelLegacy::getInstance('ReservationAsset', 'SolidresModel', array('ignore_request' => false));
				$customerTable = JTable::getInstance('Customer', 'SolidresTable');
				$customerTable->load(array('user_id' => $user->get('id')));
				$modelReservations->setState('filter.customer_id', isset($customerTable->id) ? $customerTable->id : 0 );
				$modelReservations->setState('filter.customer_email', $user->get('email') );
				$modelReservations->setState('filter.is_customer_dashboard', 1 );

				$document = JFactory::getDocument();
				$viewType = $document->getType();
				$viewName = 'Customer';
				$viewLayout = $this->input->getString('layout', 'default');

				$view = $this->getView($viewName, $viewType, '', array('base_path' => $this->basePath, 'layout' => $viewLayout));
				$view->setModel($modelReservations, true);
				$view->setModel($modelAsset);
				$view->document = $document;
				$view->display();

				break;
			case 'dashboard':
				// If the user is a guest, redirect to the login page.
				if ($user->get('guest') == 1)
				{
					// Redirect to login page.
					$return = JRoute::_('index.php?option=com_solidres&view=dashboard', false);
					$this->setRedirect(JRoute::_('index.php?option=com_users&view=login&return=' . base64_encode($return), false));

					return;
				}

				if (count(array_intersect($partnerUserGroups, $userGroups)) == 0)
				{
					JError::raiseError(403, JText::_('JERROR_ALERTNOAUTHOR'));

					return false;
				}

				parent::display($cachable, $safeurlparams);
				break;
			case 'reservationassetform':
			case 'medialist':
			case 'reservationform':
			case 'roomtypeform':
			case 'couponform':
			case 'extraform':
			case 'limitbookingform':
			case 'discountform':
				// If the user is a guest, redirect to the login page.
				if ($user->get('guest') == 1)
				{
					// Redirect to login page.
					$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));

					return;
				}
				parent::display($cachable, $safeurlparams);
				break;
			case 'reservationassets':
				if ($user->get('guest') == 1)
				{
					// Redirect to login page.
					$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));

					return;
				}

				$customerTable = JTable::getInstance('Customer', 'SolidresTable');
				$customerTable->load(array('user_id' => $user->get('id')));
				$model = JModelLegacy::getInstance('ReservationAssets', 'SolidresModel', array('ignore_request' => false));
				$model->setState('filter.partner_id', $customerTable->id);

				$document = JFactory::getDocument();
				$viewType = $document->getType();
				$viewName = 'ReservationAssets';
				$viewLayout = 'default';

				$view = $this->getView($viewName, $viewType, '', array('base_path' => $this->basePath, 'layout' => $viewLayout));
				$view->setModel($model, true);
				$view->document = $document;
				$view->display();
				break;
			case 'roomtypes':
				if ($user->get('guest') == 1)
				{
					// Redirect to login page.
					$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));

					return;
				}

				$customerTable = JTable::getInstance('Customer', 'SolidresTable');
				$customerTable->load(array('user_id' => $user->get('id')));
				$model = JModelLegacy::getInstance('RoomTypes', 'SolidresModel', array('ignore_request' => false));
				$model->setState('filter.partner_id', $customerTable->id);

				$document = JFactory::getDocument();
				$viewType = $document->getType();
				$viewName = 'RoomTypes';
				$viewLayout = 'default';

				$view = $this->getView($viewName, $viewType, '', array('base_path' => $this->basePath, 'layout' => $viewLayout));
				$view->setModel($model, true);
				$view->document = $document;
				$view->display();
				break;
			case 'reservations':
				if ($user->get('guest') == 1)
				{
					// Redirect to login page.
					$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));

					return;
				}

				$customerTable = JTable::getInstance('Customer', 'SolidresTable');
				$customerTable->load(array('user_id' => $user->get('id')));
				$model = JModelLegacy::getInstance('Reservations', 'SolidresModel', array('ignore_request' => false));
				$model->setState('filter.partner_id', $customerTable->id);

				$document = JFactory::getDocument();
				$viewType = $document->getType();
				$viewName = 'Reservations';
				$viewLayout = 'default';

				$view = $this->getView($viewName, $viewType, '', array('base_path' => $this->basePath, 'layout' => $viewLayout));
				$view->setModel($model, true);
				$view->document = $document;
				$view->display();
				break;
			case 'coupons':
				if ($user->get('guest') == 1)
				{
					// Redirect to login page.
					$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));

					return;
				}

				$customerTable = JTable::getInstance('Customer', 'SolidresTable');
				$customerTable->load(array('user_id' => $user->get('id')));

				$model = JModelLegacy::getInstance('Coupons', 'SolidresModel', array('ignore_request' => false));
				$model->setState('filter.partner_id', $customerTable->id);

				$document = JFactory::getDocument();
				$viewType = $document->getType();
				$viewName = 'Coupons';
				$viewLayout = 'default';

				$view = $this->getView($viewName, $viewType, '', array('base_path' => $this->basePath, 'layout' => $viewLayout));
				$view->setModel($model, true);
				$view->document = $document;
				$view->display();
				break;
			case 'extras':
				if ($user->get('guest') == 1)
				{
					// Redirect to login page.
					$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));

					return;
				}

				$customerTable = JTable::getInstance('Customer', 'SolidresTable');
				$customerTable->load(array('user_id' => $user->get('id')));
				$model = JModelLegacy::getInstance('Extras', 'SolidresModel', array('ignore_request' => false));
				$model->setState('filter.partner_id', $customerTable->id);

				$document = JFactory::getDocument();
				$viewType = $document->getType();
				$viewName = 'Extras';
				$viewLayout = 'default';

				$view = $this->getView($viewName, $viewType, '', array('base_path' => $this->basePath, 'layout' => $viewLayout));
				$view->setModel($model, true);
				$view->document = $document;
				$view->display();
				break;
			case 'limitbookings':
				if ($user->get('guest') == 1)
				{
					// Redirect to login page.
					$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));

					return;
				}
				$customerTable = JTable::getInstance('Customer', 'SolidresTable');
				$customerTable->load(array('user_id' => $user->get('id')));
				$model = JModelLegacy::getInstance('LimitBookings', 'SolidresModel', array('ignore_request' => false));
				$model->setState('filter.partner_id', $customerTable->id);

				$document = JFactory::getDocument();
				$viewType = $document->getType();
				$viewName = 'LimitBookings';
				$viewLayout = 'default';

				$view = $this->getView($viewName, $viewType, '', array('base_path' => $this->basePath, 'layout' => $viewLayout));
				$view->setModel($model, true);
				$view->document = $document;
				$view->display();
				break;
			case 'discounts':
				if ($user->get('guest') == 1)
				{
					// Redirect to login page.
					$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));

					return;
				}

				$customerTable = JTable::getInstance('Customer', 'SolidresTable');
				$customerTable->load(array('user_id' => $user->get('id')));
				$model = JModelLegacy::getInstance('Discounts', 'SolidresModel', array('ignore_request' => false));
				$model->setState('filter.partner_id', $customerTable->id);

				$document = JFactory::getDocument();
				$viewType = $document->getType();
				$viewName = 'Discounts';
				$viewLayout = 'default';

				$view = $this->getView($viewName, $viewType, '', array('base_path' => $this->basePath, 'layout' => $viewLayout));
				$view->setModel($model, true);
				$view->document = $document;
				$view->display();
				break;
			default:
				parent::display($cachable, $safeurlparams);
				break;
		}

		return $this;
	}
}