<?php
/*------------------------------------------------------------------------
  Solidres - Hotel booking extension for Joomla
  ------------------------------------------------------------------------
  @Author    Solidres Team
  @Website   http://www.solidres.com
  @Copyright Copyright (C) 2013 - 2016 Solidres. All Rights Reserved.
  @License   GNU General Public License version 3, or later
------------------------------------------------------------------------*/

defined('_JEXEC') or die;

class SRRouter extends JComponentRouterBase
{

	public function build(&$query)
	{
		$segments = array();

		$menus    = JFactory::getApplication()->getMenu();
		$menuItem = null;
		$db       = JFactory::getDbo();
		$sql      = $db->getQuery(true);
		if (isset($query['Itemid']))
		{
			$menuItem = $menus->getItem($query['Itemid']);
		}
		$view = isset($query['view']) ? strtolower($query['view']) : '';
		$slug = isset($query['id']) ? $query['id'] : null;
		if ($menuItem
			&& isset($menuItem->query['view'])
			&& $menuItem->query['view'] == $view
			&& isset($menuItem->query['id'])
			&& $menuItem->query['id'] == $slug
		)
		{
			unset($query['view'], $query['id']);

			return $segments;
		}

		if ($menuItem
			&& $menuItem->query['option'] == 'com_solidres'
			&& isset($menuItem->query['view'])
			&& $menuItem->query['view'] == $view
		)
		{
			unset($query['view']);
		}
		if (empty($view) && isset($query['task']) && strpos($query['task'], '.') !== false)
		{
			$task = explode('.', $query['task'], 2);
			if ($task[0] == 'reservationasset')
			{
				$view = $task[0];
			}
		}
		if ($view)
		{
			$segments[] = $view;
			unset($query['view']);
		}
		if ($slug && in_array($view, array('reservationasset', 'subscriptionform', 'experience')))
		{
			if (strpos($slug, ':') === false)
			{
				switch ($view)
				{
					case 'reservationasset':
						$sql->select('CONCAT(a.alias, ":", a.id) AS slug')
							->from($db->qn('#__sr_reservation_assets', 'a'))
							->where('a.id = ' . (int) $query['id']);
						$db->setQuery($sql);
						$slug = $db->loadResult();
						break;
					case 'subscriptionform':
						$sql->select('a.id, a.title')
							->from($db->qn('#__sr_subscription_levels', 'a'))
							->where('a.id = ' . (int) $query['id']);
						$db->setQuery($sql);
						$row  = $db->loadObject();
						$slug = JFilterOutput::stringURLSafe($row->title) . ':' . $row->id;
						break;
					case 'experience':
						$sql->select('CONCAT(a.alias, ":", a.id) AS slug')
							->from($db->qn('#__sr_experiences', 'a'))
							->where('a.id = ' . (int) $query['id']);
						$db->setQuery($sql);
						$slug = $db->loadResult();
						break;
				}
			}
		}
		if ($slug)
		{
			$segments[] = $slug;
			unset($query['id']);
		}
		if ($view == 'experiences' && isset($query['category_id']))
		{
			$sql->clear()
				->select('a.alias')
				->from($db->qn('#__sr_experience_categories', 'a'))
				->where('a.id = ' . (int) $query['category_id']);
			$db->setQuery($sql);
			if ($alias = $db->loadResult())
			{
				$segments[] = 'category:' . $alias;
				unset($query['category_id']);
			}
		}

		return $segments;
	}

	public function parse(&$segments)
	{
		$vars     = array();
		$count    = count($segments);
		if ($count > 0)
		{
			$vars['view'] = $segments[0];
			if (isset($segments[1]))
			{
				if (preg_match('/^(category\:)/', $segments[1]))
				{
					$db    = JFactory::getDbo();
					$query = $db->getQuery(true)
						->select('a.id')
						->from($db->qn('#__sr_experience_categories', 'a'))
						->where('a.alias = ' . $db->q(str_replace('category:', '', $segments[1])));
					$db->setQuery($query);
					$vars['category_id'] = (int) $db->loadResult();
				}
				else
				{
					preg_match('/([0-9]+)$/', $segments[1], $matches);
					if (!empty($matches[0]))
					{
						$vars['id'] = (int) $matches[1];
					}
					else
					{
						$vars['id'] = (int) $segments[1];
					}
				}
			}
			elseif (is_numeric($segments[0]))
			{
				$vars['id'] = (int) $segments[0];
			}
		}

		return $vars;
	}
}

function solidresBuildRoute(&$query)
{
	$router = new SRRouter;

	return $router->build($query);
}


function solidresParseRoute($segments)
{
	$router = new SRRouter;

	return $router->parse($segments);
}
