<?php
/*------------------------------------------------------------------------
  Solidres - Hotel booking extension for Joomla
  ------------------------------------------------------------------------
  @Author    Solidres Team
  @Website   http://www.solidres.com
  @Copyright Copyright (C) 2013 - 2016 Solidres. All Rights Reserved.
  @License   GNU General Public License version 3, or later
------------------------------------------------------------------------*/

defined('_JEXEC') or die;
jimport('solidres.plugin.plugin');

class plgSystemSolidres extends JPlugin
{
	protected $autoloadLanguage = true;

	protected $app;

	public function __construct($subject, $config = array())
	{
		parent::__construct($subject, $config);

		if ( file_exists(JPATH_LIBRARIES.'/solidres/defines.php') )
		{
			require_once JPATH_LIBRARIES.'/solidres/defines.php';
		}


		JLoader::import('libraries.solidres.factory', 	JPATH_ROOT);
		JLoader::import('libraries.solidres.html.html', JPATH_ROOT);
		JLoader::register('SRConfig', JPATH_LIBRARIES . '/solidres/config/config.php');
	}

	public function onAfterRoute()
	{
		JHtml::_('jquery.framework');
		$isAdmin = $this->app->isAdmin();
		$isSite  = $this->app->isSite();
		if (class_exists('SRHtml'))
		{
			SRHtml::_('js.noconflict');
			if ($isAdmin && $this->app->input->get('option') == 'com_solidres')
			{
				SRHtml::_('jquery.ui');
				SRHtml::_('js.admin');
			}
			if ($isSite)
			{
				SRHtml::_('jquery.ui');
				SRHtml::_('js.site');
			}
			SRHtml::_('js.common');
			SRHtml::_('jquery.cookie');
			SRHtml::_('jquery.validate');
		}
		JHtml::_('stylesheet', SRURI_MEDIA.'/assets/css/font-awesome.min.css', false, false);

		JPluginHelper::importPlugin('user');
		JPluginHelper::importPlugin('solidres');
		JEventDispatcher::getInstance()->trigger('onSolidresPluginRegister');

		$user         = JFactory::getUser();
		$isSuperAdmin = $user->get('isRoot');
		if ($isAdmin
			&&
			!SRPlugin::isEnabled('hub')
			&&
			$isSuperAdmin
			&&
			JFactory::getApplication()->input->get('option') == 'com_solidres'
		)
		{
			$lang = JFactory::getLanguage();
			$lang->load('com_solidres', JPATH_ADMINISTRATOR . '/components/com_solidres', null, 1);
			$dbo   = JFactory::getDbo();
			$query = $dbo->getQuery(true);
			$query->select('count(*)')->from($dbo->quoteName('#__sr_reservation_assets'))->where($dbo->quoteName('default') .' = 1');
			$count = $dbo->setQuery($query)->loadResult();

			if ($count >= 2)
			{
				JFactory::getApplication()->enqueueMessage(JText::_('SR_WARNING_MORE_THAN_1_DEFAUT_IS_NOT_ALLOWED'), 'warning');
			}
			else if ($count == 0)
			{
				JFactory::getApplication()->enqueueMessage(JText::_('SR_WARNING_REQUIRE_AT_LEAST_1_DEFAULT_ASSET'), 'warning');
			}
		}		

		if (SRPlugin::isEnabled('advancedextra'))
		{
			JLoader::register('SRExtra', JPATH_PLUGINS . '/solidres/advancedextra/libraries/extra/extra.php');
		}
		else
		{
			JLoader::register('SRExtra', JPATH_LIBRARIES . '/solidres/extra/extra.php');
		}

		JFactory::getDocument()->addScriptDeclaration('
			(function() {
				Solidres.options.load({
					"Hub":' . (SRPlugin::isEnabled('hub') ? 1 : 0) . ',
					"ChannelManager":' . (SRPlugin::isEnabled('channelmanager') ? 1 : 0) . ',
				});
			})();	
				
			Solidres.jQuery(function($) {	
				// Turn radios into btn-group
				$("#solidres .radio").addClass("btn-group").removeClass("t3onoff");
			    $("#solidres .radio.btn-group label").addClass("btn btn-default");
			    $("#solidres .btn-group label:not(.active)").click(function()
			    {
			        var label = $(this);
			        var input = $("#" + label.attr("for"));
			
			        if (!input.prop("checked")) {
			            label.closest(".btn-group").find("label").removeClass("active btn-success btn-danger btn-primary");
			            if (input.val() == "") {
			                label.addClass("active btn-primary");
			            } else if (input.val() == 0) {
			                label.addClass("active btn-danger");
			            } else {
			                label.addClass("active btn-success");
			            }
			            input.prop("checked", true);
			            input.trigger("change");
			        }
			    });
			
			    $("#solidres .btn-group input[checked=checked]").each(function()
			    {
			        if ($(this).val() == "") {
			            $("label[for=" + $(this).attr("id") + "]").addClass("active btn-primary");
			        } else if ($(this).val() == 0) {
			            $("label[for=" + $(this).attr("id") + "]").addClass("active btn-danger");
			        } else {
			            $("label[for=" + $(this).attr("id") + "]").addClass("active btn-success");
			        }
			    });
			});
		');

		if($isSite)
		{
			$solidresConfig = JComponentHelper::getParams('com_solidres');
			if ($solidresConfig->get('enable_carousel_compat', 0))
			{
				JFactory::getDocument()->addScriptDeclaration('
				    window.addEvent("domready", function() {
						if (typeof jQuery != "undefined" && typeof MooTools != "undefined" ) {
							Element.implement({
								slide: function(how, mode) {
									return this;
								}
							});
						}
					});
				');
			}
		}
	}

	public function onAfterRender()
	{
		$solidresConfig = JComponentHelper::getParams('com_solidres');

		$solidresConfigData = new SRConfig(array('scope_id' => 0, 'data_namespace' => 'system'));
		$lastUpdateCheck = $solidresConfigData->get('system/last_update_check', '');
		$needUpdateChecking = false;
		$updateSourceFile = JPATH_ADMINISTRATOR . '/components/com_solidres/views/system/cache/updates.json';

		if ($this->app->isAdmin())
		{
			if (empty($lastUpdateCheck) || !JFile::exists($updateSourceFile))
			{
				$needUpdateChecking = true;
			}
			else
			{
				$now = JFactory::getDate('now', 'UTC');
				$nextRun = JFactory::getDate($lastUpdateCheck, 'UTC');
				$nextRun->add(new DateInterval('PT24H'));

				if ($now->toUnix() > $nextRun->toUnix())
				{
					$needUpdateChecking = true;
				}
			}

			if ($needUpdateChecking)
			{
				JLoader::register('SolidresControllerSystem', JPATH_ADMINISTRATOR . '/components/com_solidres/controllers/system.php');
				$solidresSystemCtrl = new SolidresControllerSystem();
				$url = 'https://www.solidres.com/checkupdates';
				$solidresSystemCtrl->postFindUpdates($url);
				$solidresConfigData->set(array('last_update_check' => JFactory::getDate('now', 'UTC')->toUnix()));
			}
		}

		if ($solidresConfig->get('enable_multilingual_mode', 1) == 1)
		{
			/* Translate custom field by using language tag. Author: isApp.it Team */
			// TODO consolidate into SRUtilitises class
			if (JFactory::getApplication()->isAdmin() ) return true;

			$buffer = JResponse::getBody();

			if ( strpos( $buffer, '{lang' ) === false ) return true;

			$regexTextarea = "#<textarea(.*?)>(.*?)<\/textarea>#is";
			$regexInput = "#<input(.*?)>#is";

			$matches = array();
			preg_match_all($regexTextarea, $buffer, $matches, PREG_SET_ORDER);
			$textarea = array();
			foreach ($matches as $key => $match)
			{
				if (strpos($match[0], '{lang') !== false)
				{
					$textarea[$key] = $match[0];
					$buffer = str_replace($textarea[$key], '~^t'.$key.'~', $buffer);
				}
			}

			$matches = array();
			preg_match_all($regexInput, $buffer, $matches, PREG_SET_ORDER);
			$input = array();
			foreach ($matches as $key => $match)
			{
				if(
					(strpos( $match[0], 'type="password"' ) !== false ||
					 strpos( $match[0], 'type="text"' ) !== false) &&
					strpos($match[0], '{lang') !== false
				)
				{
					$input[$key] = $match[0];
					$buffer = str_replace($input[$key], '~^i'.$key.'~', $buffer);
				}
			}

			if (strpos($buffer, '{lang') !== false)
			{
				$buffer = plgSystemSolidres::filterText($buffer);

				if ($textarea)
				{
					foreach ($textarea as $key => $t)
					{
						$buffer = str_replace('~^t'.$key.'~', $t, $buffer);
					}
					unset($textarea);
				}
				if ($input)
				{
					foreach ($input as $key => $i)
					{
						$buffer = str_replace('~^i'.$key.'~', $i, $buffer);
					}
					unset($input);
				}
				JResponse::setBody($buffer);
			}

			unset($buffer);
		}
	}

	/* Translate custom field by using language tag. Author: isApp.it Team */
	// TODO consolidate into SRUtilitises class
	static function getLagnCode()
	{
		$lang_codes = JLanguageHelper::getLanguages('lang_code');
		$lang_code 	= $lang_codes[JFactory::getLanguage()->getTag()]->sef;
		return $lang_code;
	}

	/* Translate custom field by using language tag. Author: isApp.it Team */
	// TODO consolidate into SRUtilitises class
	static function filterText($text)
	{
		if ( strpos( $text, '{lang' ) === false ) return $text;
		$lang_code = plgSystemSolidres::getLagnCode();
		$regex = "#{lang ".$lang_code."}(.*?){\/lang}#is";
		$text = preg_replace($regex,'$1', $text);
		$regex = "#{lang [^}]+}.*?{\/lang}#is";
		$text = preg_replace($regex,'', $text);
		return $text;
	}
}