<?php
/*------------------------------------------------------------------------
  Solidres - Hotel booking extension for Joomla
  ------------------------------------------------------------------------
  @Author    Solidres Team
  @Website   http://www.solidres.com
  @Copyright Copyright (C) 2013 - 2016 Solidres. All Rights Reserved.
  @License   GNU General Public License version 3, or later
------------------------------------------------------------------------*/

defined('_JEXEC') or die;

JLoader::register('SRPayment', SRPATH_LIBRARY . '/payment/payment.php');
use Omnipay\Omnipay;
use Joomla\Registry\Registry;

abstract class SRPaymentOmnipayAbstract extends SRPayment
{
	protected $autoloadLanguage = true;

	/** @var $db JDatabaseDriver */
	protected $db;

	/** @var $app JApplicationCms */
	protected $app;

	/** @var $dataConfig Array */
	protected $dataConfig;

	abstract protected function getForm();

	abstract protected function getGateWay();

	abstract protected function appendPaymentNew($gateway, $amount, $currencyCode, $reservationData);

	abstract protected function appendPaymentCallBack($paymentMethodId, $callbackData);

	public function __construct($subject, $config = array())
	{
		parent::__construct($subject, $config);

		$name              = str_ireplace('PlgSolidresPayment', '', get_class($this));
		$this->identifier  = is_callable(array($this, 'getIdentifier')) ? $this->getIdentifier() : strtolower($name);
		$this->title       = JText::_('PLG_SOLIDRESPAYMENT_' . strtoupper($name));
		$this->description = JText::_('PLG_SOLIDRESPAYMENT_' . strtoupper($name) . '_XML_DESCRIPTION');
	}

	protected function getConfig($scopeId = 0)
	{
		$options = array('data_namespace' => 'payments/' . $this->identifier);

		if ($scopeId > 0)
		{
			$options['scope_id'] = (int) $scopeId;
		}

		$config = new SRConfig($options);

		return $config;
	}

	public function onReservationAssetPrepareForm($form, $data)
	{
		$this->loadLanguage();

		if (!($form instanceof JForm))
		{
			$this->_subject->setError('JERROR_NOT_A_FORM');

			return false;
		}

		// Check we are manipulating a valid form.
		if (!in_array($form->getName(), array('com_solidres.reservationasset')))
		{
			return true;
		}

		if ($load = $form->loadFile($this->getForm(), false))
		{
			if (isset($data->id) && ($paymentData = $this->loadFormData($data->id)))
			{
				$form->bind(array('payments' => $paymentData));
			}
		}

		return $load;
	}

	protected function loadFormData($scopeId = 0)
	{
		$db    = JFactory::getDbo();
		$query = $db->getQuery(true)
			->select('a.data_key, a.data_value')
			->from($db->qn('#__sr_config_data', 'a'))
			->where('a.data_key LIKE ' . $db->q('payments/' . $this->identifier . '/%'))
			->where('a.scope_id = ' . (int) $scopeId);		

		$db->setQuery($query);

		if ($data = $db->loadObjectList('data_key'))
		{
			$temp = array();

			foreach ($data as $k => $v)
			{
				$k        = str_replace('payments/' . $this->identifier . '/', '', $k);
				$temp[$k] = $v->data_value;
				if (is_string($temp[$k]) && is_array(json_decode($temp[$k], true)) && (json_last_error() == JSON_ERROR_NONE))
				{
					$temp[$k] = json_decode($temp[$k], true);
				}
			}

			$data = $temp;
		}

		return $data;
	}

	public function onReservationAssetAfterSave($data, $table, $result, $isNew)
	{
		if (!$result || empty($data['payments']))
		{
			return;
		}

		$saveData = array();

		foreach ($data['payments'] as $k => $v)
		{
			if (is_array($v) || is_object($v))
			{
				$registry = new Registry($v);
				$v        = (string) $registry->toString();
			}

			if (strpos($k, $this->identifier) === 0)
			{
				$saveData[$k] = $v;
			}
		}

		if (is_callable(array($this, 'prepareSaveData')))
		{
			call_user_func_array(array($this, 'prepareSaveData'), array($table, &$saveData));
		}

		if (count($saveData))
		{
			$config = $this->getConfig($table->id);

			$config->set($saveData);
		}
	}

	public function onSolidresPaymentNew($reservationData)
	{
		if ($reservationData->payment_method_id != $this->identifier)
		{
			return false;
		}

		static $log;

		if ($log == null)
		{
			$options['format']    = '{DATE}\t{TIME}\t{LEVEL}\t{CODE}\t{MESSAGE}';
			$options['text_file'] = 'solidres_' . $this->identifier . '_request.php';
			$log                  = JLog::addLogger($options);
		}

		JLog::add('Start payment processing', JLog::DEBUG);

		JTable::addIncludePath(JPATH_ADMINISTRATOR . '/components/com_solidres/tables');
		$tableCountry = JTable::getInstance('Country', 'SolidresTable');
		$tableCountry->load($reservationData->customer_country_id);

		$this->dataConfig = $this->loadFormData((int) $reservationData->reservation_asset_id);

		$amountToBePaid = $this->getPayAmount($reservationData);

		JLoader::import($this->_name . '.vendor.autoload', JPATH_PLUGINS . '/' . $this->_type);
		$gateway         = Omnipay::create($this->getGateWay());
		$this->returnUrl = $this->getReturnUrl($reservationData->id);

		return $this->appendPaymentNew($gateway, $amountToBePaid, $reservationData->currency_code, $reservationData);
	}

	public function OnSolidresPaymentCallback($paymentMethodId, $callbackData)
	{
		if ($paymentMethodId != $this->identifier || empty($callbackData))
		{
			return false;
		}

		static $log;

		if ($log == null)
		{
			$options['format']    = '{DATE}\t{TIME}\t{LEVEL}\t{CODE}\t{MESSAGE}';
			$options['text_file'] = 'solidres_' . $this->identifier . '_response.php';
			$log                  = JLog::addLogger($options);
		}

		return $this->appendPaymentCallBack($paymentMethodId, $callbackData);
	}

	public function onSolidresPaymentRefundDisplay(JForm $reservation)
	{
		return;
	}

	public function onSolidresPaymentRefundCallback()
	{
		return;
	}
}
